grib2io.tables.section6 API documentation

# grib2io.tables.section6

View Source

    1table_6_0 = {
    2'0':'A bit map applies to this product and is specified in this section.',
    3'1-253':'A bit map pre-determined by the orginating/generating center applies to this product and is not specified in this section.',
    4'254':'A bit map previously defined in the same GRIB2 message applies to this product.',
    5'255':'A bit map does not apply to this product.',
    6}